@@ -2,6 +2,7 @@ class InvalidToken(Exception):
     def __init__(self, *args: object) -> None:
         super().__init__(*args)
 
-class UnkownError(Exception):
+
+class UnknownError(Exception):
     def __init__(self, *args: object) -> None:
-        super().__init__(*args)
\ No newline at end of file
+        super().__init__(*args)
